;; Generated package description from wisitoken-grammar-mode.el  -*- no-byte-compile: t -*-
(define-package "wisitoken-grammar-mode" "1.0.0" "Major mode for editing WisiToken grammar files" '((wisi "2.1.1") (emacs "25.0") (mmm-mode "0.5.7")) :url "http://elpa.gnu.org/packages/wisitoken-grammar-mode.html" :keywords '("languages") :authors '(("Stephen Leake" . "stephen_leake@stephe-leake.org")) :maintainer '("Stephen Leake" . "stephen_leake@stephe-leake.org"))
